Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/owncloud/client.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPhil Davis <phil@jankaritech.com>2022-02-23 12:49:10 +0300
committerHannah von Reth <vonreth@kde.org>2022-02-23 19:48:02 +0300
commit1334d663d6821fb3d8aac7e4caa9c26cc3c8b5f6 (patch)
treeba5e40361cb20b64bf2d10b6ffdfd1fc6cabd0c6 /src/gui/folderman.cpp
parentddbbb1de4cda1d1cacfea4083042d213a689821c (diff)
Set etagPollTimer interval to 10 seconds
Diffstat (limited to 'src/gui/folderman.cpp')
-rw-r--r--src/gui/folderman.cpp10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/gui/folderman.cpp b/src/gui/folderman.cpp
index 32a9acc6b..efaecf6aa 100644
--- a/src/gui/folderman.cpp
+++ b/src/gui/folderman.cpp
@@ -145,10 +145,12 @@ FolderMan::FolderMan(QObject *parent)
_socketApi.reset(new SocketApi);
- // Set the remote poll interval fixed to 1 second (1000 milliseconds)
- // That does not mean that it polls every 1 second, but it checks every 1 second
- // if one of the folders is due to sync.
- _etagPollTimer.setInterval(1000);
+ // Set the remote poll interval fixed to 10 seconds.
+ // That does not mean that it polls every 10 seconds, but it checks every 10 seconds
+ // if one of the folders is due to sync. This means that if the server advertises a
+ // pollinterval that is not a multiple of 10 seconds, then that pollinterval will be
+ // rounded up to the next 10 seconds in practice. 10-second granularity is acceptable.
+ _etagPollTimer.setInterval(10s);
QObject::connect(&_etagPollTimer, &QTimer::timeout, this, &FolderMan::slotEtagPollTimerTimeout);
_etagPollTimer.start();